@@ -1,25 +1,22 @@
 /*
+Copyright (C) 2001 - 2013 Evan Teran
+                          evan.teran@gmail.com
 
-    KCalc, a scientific calculator for the X window system using the
-    Qt widget libraries, available at no cost at http://www.troll.no
+Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
+                          wuebben@kde.org
 
-    Copyright (C) 1996 Bernd Johannes Wuebben
-                       wuebben@math.cornell.edu
+This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License as
+published by the Free Software Foundation; either version 2 of 
+the License, or (at your option) any later version.
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
 
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef KCALC_CORE_H_
@@ -29,15 +26,6 @@
 #include "stats.h"
 #include "knumber.h"
 
-typedef KNumber(*Arith)(const KNumber &, const KNumber &);
-typedef KNumber(*Prcnt)(const KNumber &, const KNumber &);
-
-struct operator_data {
-    int precedence;  // priority of operators in " enum Operation"
-    Arith arith_ptr;
-    Prcnt prcnt_ptr;
-};
-
 class CalcEngine {
 public:
     // operations that can be stored in calculation stack
@@ -150,9 +138,6 @@ private:
 
     bool percent_mode_;
 
-
-    static const struct operator_data Operator[];
-
     bool evalStack();
 
     KNumber evalOperation(const KNumber &arg1, Operation operation, const KNumber &arg2);
